@@ -62,7 +62,7 @@ class Request(Bunch):
         """
 
         # No JSON-String
-        if json_string is None:
+        if not json_string:
             raise rpcerror.InvalidRequest()
 
         # Parse
@@ -125,13 +125,37 @@ class Request(Bunch):
     dumps = to_string
 
 
+    def to_dict(self):
+        """
+        Returns the request as dictionary
+        """
+
+        return self.toDict()
+
+
+    @classmethod
+    def from_dict(cls, data):
+        """
+        Returns a request-object, created from Dictionary.
+
+        :rtype: Request
+        """
+
+        return cls(
+            jsonrpc = data.get("jsonrpc"),
+            method = data.get("method"),
+            id = data.get("id"),
+            params = data.get("params")
+        )
+
+
 # Alias for *Request.loads*
 parse_request_json = Request.from_string
 
 
 def create_request_dict(method, *args, **kwargs):
     """
-    Returns a JSON-RPC-Dictionary for a method
+    Returns a JSON-RPC-dictionary for a method
 
     :param method: Name of the method
     :param args: Positional parameters
